@@ -1,9 +1,12 @@
 
 package MooseX::AttributeHelpers;
 
-our $VERSION   = '0.12';
+our $VERSION   = '0.13';
+$VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
+use Moose 0.56 ();
+
 use MooseX::AttributeHelpers::Meta::Method::Provided;
 use MooseX::AttributeHelpers::Meta::Method::Curried;
 
