@@ -2,10 +2,6 @@
 package MooseX::AttributeHelpers::Meta::Method::Curried;
 use Moose;
 
-our $VERSION   = '0.17';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 extends 'Moose::Meta::Method';
 
 1;
@@ -42,7 +38,7 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2009 by Infinity Interactive, Inc.
+Copyright 2007-2008 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
